@@ -12,20 +12,23 @@
 #'  Spectral columns must be labeled with an "X" and then the wavelength
 #'  (example: "X740" = 740nm). Left-most column must be unique ID. May also
 #'  contain columns of metadata between the unique ID and spectral columns.
-#'  Cannot contain any missing values. Metadata column names may not start with "X".
+#'  Cannot contain any missing values. Metadata column names may not start
+#'  with "X".
 #' @param num.col.before.spectra Number of columns to the left of the spectral
 #'  matrix (including unique ID). Default is 1.
-#' @param detect.outliers Boolean indicating whether spectra should be filtered before plotting.
-#'  If \code{TRUE}, outliers are indicated by color in the resulting plot. If
-#'  \code{verbose} is also set to \code{TRUE}, outlier metadata will be printed to
-#'  the console. Default is \code{TRUE}.
+#' @param detect.outliers Boolean indicating whether spectra should be filtered
+#'  before plotting. If \code{TRUE}, outliers are indicated by color in the
+#'  resulting plot. If \code{verbose} is also set to \code{TRUE}, outlier
+#'  metadata will be printed to the console. Default is \code{TRUE}.
 #' @param color String or vector of strings indicating colors to be passed to
-#'  \code{\link[ggplot2]{ggplot}}. Default is default \code{\link[ggplot2]{ggplot}} colors.
-#' @param alternate.title String to be used as plot title. If \code{detect.outliers} is
-#'  \code{TRUE}, a descriptive title will be supplied. If \code{detect.outliers} is
-#'  \code{FALSE}, default is no title will be used.
+#'  \code{\link[ggplot2]{ggplot}}. Default is default
+#'  \code{\link[ggplot2]{ggplot}} colors.
+#' @param alternate.title String to be used as plot title. If
+#'  \code{detect.outliers} is \code{TRUE}, a descriptive title will be supplied.
+#'  If \code{detect.outliers} is \code{FALSE}, default is no title will be used.
 #' @param wavelengths DEPRECATED \code{wavelengths} is no
-#'  longer supported; this information is now inferred from \code{df} column names
+#'  longer supported; this information is now inferred from
+#'  \code{df} column names
 #'
 #' @importFrom dplyr select mutate distinct
 #' @importFrom tidyselect starts_with
@@ -37,9 +40,9 @@
 #' @importFrom rlang .data abort
 #' @importFrom lifecycle deprecated
 #'
-#' @return If verbose, prints unique ID and metadata for rows identified as outliers.
-#'  Returns plot of spectral data with non-outliers in blue and outliers in red.
-#'  X-axis is wavelengths and y-axis is spectral values.
+#' @return If verbose, prints unique ID and metadata for rows identified as
+#' outliers. Returns plot of spectral data with non-outliers in blue and
+#' outliers in red. X-axis is wavelengths and y-axis is spectral values.
 #' @export
 #'
 #' @examples
@@ -75,18 +78,21 @@ plot_spectra <- function(df,
   # Error handling ---------------------------
   # mahalanobis function does not allow missing values or non-numeric data
   if (nrow(spectra) != nrow(na.omit(spectra))) {
-    rlang::abort("Input data frame cannot contain missing values! Remove them and try again.")
+    rlang::abort("Input data frame cannot contain missing values!
+                 Remove them and try again.")
   }
 
   if (detect.outliers) { # Outlier detection
 
     # Color-related handling ---------------------------
-    if (!is.null(color) & length(color) == 1) {
-      rlang::abort("Two colors are required but only one was supplied. Please add another value or set 'color' to 'NULL'")
+    if (!is.null(color) && length(color) == 1) {
+      rlang::abort("Two colors are required but only one was supplied.
+                   Please add another value or set 'color' to 'NULL'")
     }
 
-    if (!is.null(color) & length(color) > 2) {
-      warning("Two colors are required but more than two were supplied. Only the first two will be used.")
+    if (!is.null(color) && length(color) > 2) {
+      warning("Two colors are required but more than two were supplied.
+              Only the first two will be used.")
       color <- color[1:2]
     }
 
@@ -108,7 +114,8 @@ plot_spectra <- function(df,
 
     # Plot title ---------------------------
     if (is.null(alternate.title)) {
-      plot.title <- paste0("Chi-Square (", length(wavelengths), " df) 95% cutoff for Mahalanobis distance")
+      plot.title <- paste0("Chi-Square (", length(wavelengths),
+                           " df) 95% cutoff for Mahalanobis distance")
     } else {
       plot.title <- alternate.title
     }
@@ -116,7 +123,7 @@ plot_spectra <- function(df,
     # Calculate outlier cutoff ---------------------------
     chisq95 <- qchisq(.95, df = length(wavelengths))
 
-    # Calculate Mahalanobis distribution for each scan and identify outliers ---------------------------
+    # Calculate Mahalanobis distribution for each scan and identify outliers ---
     filtered.df <- filter_spectra(
       df = df, filter = FALSE, return.distances = TRUE,
       num.col.before.spectra = num.col.before.spectra,
@@ -127,8 +134,10 @@ plot_spectra <- function(df,
     # Prepare data frame for plotting ---------------------------
     hdists.df <- filtered.df %>%
       tibble::rownames_to_column(var = "rownames") %>%
-      dplyr::select(.data$rownames, .data$h.distances, .data$Outlier, tidyselect::starts_with("X")) %>%
-      tidyr::gather(key = "wl", value = "s.value", tidyselect::starts_with("X")) %>%
+      dplyr::select(.data$rownames, .data$h.distances, .data$Outlier,
+                    tidyselect::starts_with("X")) %>%
+      tidyr::gather(key = "wl", value = "s.value",
+                    tidyselect::starts_with("X")) %>%
       dplyr::mutate(wl = as.numeric(readr::parse_number(.data$wl)))
 
     # Create plot ---------------------------
@@ -142,7 +151,8 @@ plot_spectra <- function(df,
       )
     ) +
       geom_line(alpha = .5) +
-      geom_line(data = subset(hdists.df, hdists.df$Outlier == T), alpha = .7) +
+      geom_line(data = subset(hdists.df, hdists.df$Outlier == TRUE),
+                alpha = .7) +
       scale_color_manual(values = color, name = "Outlier?") +
       theme_minimal() +
       labs(
@@ -156,8 +166,10 @@ plot_spectra <- function(df,
       if (sum(hdists.df$Outlier > 0)) {
         cat("Outliers:\n")
         print(
-          filtered.df %>% dplyr::filter(.data$h.distances > chisq95) %>%
-            dplyr::select(-tidyselect::starts_with("X")) %>% distinct()
+          filtered.df %>%
+            dplyr::filter(.data$h.distances > chisq95) %>%
+            dplyr::select(-tidyselect::starts_with("X")) %>%
+            distinct()
         )
       } else {
         cat("No outliers detected.\n")
@@ -166,8 +178,9 @@ plot_spectra <- function(df,
   } else { # No outlier detection
 
     # Color handling ---------------------------
-    if (!is.null(color) & length(color) > 1) {
-      warning("Only one color is required but more than one were supplied. Only the first value will be used")
+    if (!is.null(color) && length(color) > 1) {
+      warning("Only one color is required but more than one were supplied.
+              Only the first value will be used")
       color <- color[1]
     }
 
@@ -184,8 +197,10 @@ plot_spectra <- function(df,
     prepped.df <- df %>%
       tibble::rownames_to_column(var = "rownames") %>%
       dplyr::select(.data$rownames, tidyselect::starts_with("X")) %>%
-      tidyr::gather(key = "wl", value = "s.value", tidyselect::starts_with("X")) %>%
-      dplyr::mutate(wl = as.numeric(stringr::str_extract(.data$wl, "\\-*\\d+\\.*\\d*")))
+      tidyr::gather(key = "wl", value = "s.value",
+                    tidyselect::starts_with("X")) %>%
+      dplyr::mutate(wl = as.numeric(stringr::str_extract(.data$wl,
+                                                         "\\-*\\d+\\.*\\d*")))
 
     spectral.plot <- ggplot(
       data = prepped.df,
